IFLRs' relations to EFLRs
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The relations of :ref:`Frame Data` and :ref:`No-Format Frame Data` to their 'parent' :ref:`EFLR <EFLRs>` objects
is summarised below.
For explanation on the differences between ``FrameSet`` and ``FrameItem`` etc., please see :ref:`EFLRSet and EFLRItem`.

.. mermaid:: ../../class-diagrams/iflrs-vs-eflrs.mmd
